==> img0ch-2.1.9.zip: img0ch/_template/type/error.cs <==
<?xml version="1.0" encoding="shift_jis"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
  "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
<head>
<title>ERRORI</title>
<meta http-equiv="Content-Type" content="text/html; charset=shift_jis" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="generator" content="<?cs var:html_escape(VERSION ESCAPE) ?>" />
<link media="all" href="<?cs var:html_escape(StaticURI) ?>/tdiary/base.css" rel="stylesheet" />
<link media="all" href="<?cs var:html_escape(StaticURI) ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:html_escape(BBS_TYPE_THEME) ?>/<?cs var:html_escape(BBS_TYPE_THEME) ?>.css<?cs else ?>default/default.css<?cs /if ?>" rel="stylesheet" />
</head>
<body>

<h1>ERROR!</h1>
<hr class="sep" />

<?cs if:Flag ?>
<div class="day" id="error">
 <h2><span class="title">G[߁A݂͒f܂B</span></h2>
 <div class="body">
  <div class="caption"><?cs var:html_escape(LongErrorStr) ?></div>
  <div class="section">
   <p>
    zXgF&nbsp;<?cs var:html_escape(Host) ?><br />
    OF&nbsp;<b><?cs var:html_escape(Name) ?></b><br />
    E-mailF&nbsp;<?cs var:html_escape(Mail) ?><br />
    eF<br /><?cs var:html_escape(Message) ?>
    <br />
    <a href="<?cs var:html_escape(BBSURI) ?>/" rel="nofollow">炩珑݌̌fɖ߂邱Ƃo܂B</a>
   </p>
  </div>
 </div>
</div>
<?cs else ?>
<div class="day" id="error">
 <h2><span class="title">G[߁Aw肳ꂽXbhǂݍނƂo܂</span></h2>
 <div class="body">
  <div class="caption"><?cs var:html_escape(LongErrorStr) ?></div>
  <div class="section">
   <p><a href="<?cs var:html_escape(BBSURI) ?>/">炩珑݌̌fɖ߂邱Ƃo܂B</a></p>
  </div>
 </div>
</div>
<?cs /if ?>

<hr class="sep" />
<div class="footer">
 <?cs var:html_escape(VERSION ESCAPE) ?>
</div>

</body>
</html>

==> img0ch-2.1.11.zip: img0ch/_template/type/error.cs <==
<?cs if:IsMobile ?>

<html>
<head>
<title>ERROR!</title>
<meta http-equiv="Content-Type" content="text/html;charset=sjis">
</head>
<body>
<b><?cs var:html_escape(LongErrorStr) ?></b>
<p><a href="<?cs if:KEY ?><?cs var:html_escape(CGIURI) ?>/r.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(KEY) ?>/i<?cs else ?><?cs var:html_escape(BBSURI) ?>/i/<?cs /if ?>">[h</a></p>

<?cs else ?>

<?xml version="1.0" encoding="shift_jis"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
  "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">

<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja">
<head>
<title>ERRORI</title>
<meta http-equiv="Content-Type" content="text/html; charset=shift_jis" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta name="generator" content="<?cs var:html_escape(VERSION) ?>" />
<link media="all" href="<?cs var:html_escape(StaticURI) ?>/tdiary/base.css" rel="stylesheet" />
<link media="all" href="<?cs var:html_escape(StaticURI) ?>/tdiary/<?cs if:BBS_TYPE_THEME ?><?cs var:html_escape(BBS_TYPE_THEME) ?>/<?cs var:html_escape(BBS_TYPE_THEME) ?>.css<?cs else ?>default/default.css<?cs /if ?>" rel="stylesheet" />
</head>
<body>

<h1>ERROR!</h1>
<hr class="sep" />

<?cs if:Flag ?>
<div class="day" id="error">
 <h2><span class="title">G[߁A݂͒f܂B</span></h2>
 <div class="body">
  <div class="caption"><?cs var:html_escape(LongErrorStr) ?></div>
  <div class="section">
   <p>
    zXgF&nbsp;<?cs var:html_escape(Host) ?><br />
    OF&nbsp;<b><?cs var:html_escape(Name) ?></b><br />
    E-mailF&nbsp;<?cs var:html_escape(Mail) ?><br />
    eF<br /><?cs var:html_escape(Message) ?>
    <br />
    <a href="<?cs var:html_escape(BBSURI) ?>/" rel="nofollow">炩珑݌̌fɖ߂邱Ƃo܂B</a>
   </p>
  </div>
 </div>
</div>
<?cs else ?>
<div class="day" id="error">
 <h2><span class="title">G[߁Aw肳ꂽXbhǂݍނƂo܂</span></h2>
 <div class="body">
  <div class="caption"><?cs var:html_escape(LongErrorStr) ?></div>
  <div class="section">
   <p><a href="<?cs var:html_escape(BBSURI) ?>/">炩珑݌̌fɖ߂邱Ƃo܂B</a></p>
  </div>
 </div>
</div>
<?cs /if ?>

<hr class="sep" />
<div class="footer">
 <?cs var:html_escape(VERSION) ?>
</div>

<?cs /if ?>

</body>
</html>
